@@ -1,6 +1,8 @@
 use serde::ser::{Serialize, Serializer};
-use std::time::Duration;
 
+/// The type used for sample and marker timestamps.
+///
+/// Timestamps in the profile are stored in reference to the profile's [`ReferenceTimestamp`](crate::ReferenceTimestamp).
 #[derive(Debug, Clone, Copy, PartialOrd, Ord, PartialEq, Eq, Hash)]
 pub struct Timestamp {
     nanos: u64,
@@ -16,12 +18,6 @@ impl Timestamp {
             nanos: (millis * 1_000_000.0) as u64,
         }
     }
-
-    pub fn from_duration_since_reference(duration: Duration) -> Self {
-        Self {
-            nanos: duration.as_nanos() as u64,
-        }
-    }
 }
 
 impl Serialize for Timestamp {
